@@ -742,7 +742,7 @@ static GtkActionEntry entries[] = {
 	
 	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Open the help contents for the Configuration Editor"), 
 	  G_CALLBACK (help_cb) },
-	{ "AboutAction", GNOME_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the Configuration Editor"), 
+	{ "AboutAction", GTK_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the Configuration Editor"), 
 	  G_CALLBACK (gconf_editor_window_about_window) },
 
 	{ "NewKey", GTK_STOCK_NEW, N_("_New Key..."), "<control>N", N_("Create a new key"),
@@ -877,7 +877,6 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 		gconf_list_model_set_root_path (GCONF_LIST_MODEL (window->list_model), path);
 
 		g_free (path);
-
 	}
 }
 
@@ -1115,6 +1114,9 @@ gconf_editor_window_update_list_selection (GtkTreeSelection *selection, GConfEdi
 		gtk_widget_hide (window->no_schema_label);
 	}
 
+	if (schema != NULL)
+		gconf_schema_free (schema);
+
 	gtk_statusbar_pop (GTK_STATUSBAR (window->statusbar), 0);
 	gtk_statusbar_push (GTK_STATUSBAR (window->statusbar), 0, path);
 
